@@ -6,12 +6,12 @@
 #    By: charles <charles.cabergs@gmail.com>        +#+  +:+       +#+         #
 #                                                 +#+#+#+#+#+   +#+            #
 #    Created: 2020/07/15 18:24:48 by charles           #+#    #+#              #
-#    Updated: 2021/02/05 15:09:57 by charles          ###   ########.fr        #
+#    Updated: 2021/02/05 15:16:25 by charles          ###   ########.fr        #
 #                                                                              #
 # ############################################################################ #
 
-# import os
-# import glob
+import os
+import glob
 
-# modules = glob.glob(os.path.join(os.path.dirname(__file__), "*.py"))
-# __all__ = [os.path.basename(f)[:-3] for f in modules if os.path.isfile(f) and not f.endswith("__init__.py")]
+modules = glob.glob(os.path.join(os.path.dirname(__file__), "*.py"))
+__all__ = [os.path.basename(f)[:-3] for f in modules if os.path.isfile(f) and not f.endswith("__init__.py")]
